@@ -1,5 +1,5 @@
 /*
- * SPDX-FileCopyrightText: 2020-2023 Laurent Montel <montel@kde.org>
+ * SPDX-FileCopyrightText: 2020-2024 Laurent Montel <montel@kde.org>
  *
  * SPDX-License-Identifier: LGPL-2.0-or-later
  */
@@ -17,8 +17,8 @@ LdapWidgetItemReadConfigServerJob::~LdapWidgetItemReadConfigServerJob() = defaul
 
 void LdapWidgetItemReadConfigServerJob::start()
 {
-    auto job = new LdapClientSearchConfigReadConfigJob(this);
-    connect(job, &LdapClientSearchConfigReadConfigJob::configLoaded, this, &LdapWidgetItemReadConfigServerJob::slotConfigLoaded);
+    auto job = new KLDAPCore::LdapClientSearchConfigReadConfigJob(this);
+    connect(job, &KLDAPCore::LdapClientSearchConfigReadConfigJob::configLoaded, this, &LdapWidgetItemReadConfigServerJob::slotConfigLoaded);
     job->setActive(mActive);
     job->setConfig(mConfig);
     job->setServerIndex(mCurrentIndex);
